Package: SongEvo
Title: An Individual-Based Model of Bird Song Evolution
Version: 1.0.0
Authors@R: c(
  person("Raymond", "Danner", email = "dannerR@uncw.edu", role = c("aut", "cre")),
  person("Elizabeth", "Derryberry", role = "aut"),
  person("Graham", "Derryberry", role = "aut"),
  person("Julie", "Danner", role = "aut"),
  person("David", "Luther", role = "aut"))
BugReports: https://github.com/raydanner/SongEvo/issues
Description: Simulates the cultural evolution of quantitative traits of bird song. 'SongEvo' is an individual- (agent-) based model. 'SongEvo' is spatially-explicit and can be parameterized with, and tested against, measured song data. Functions are available for model implementation, sensitivity analyses, parameter optimization, model validation, and hypothesis testing. 
Depends: R (>= 3.1.0)
Imports: boot, geosphere, lattice, sp
Suggests: reshape2, Hmisc, knitr, rmarkdown
License: GPL-3
LazyData: true
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 6.1.1
NeedsCompilation: no
Packaged: 2019-03-02 20:00:19 UTC; dannerr
Author: Raymond Danner [aut, cre],
  Elizabeth Derryberry [aut],
  Graham Derryberry [aut],
  Julie Danner [aut],
  David Luther [aut]
Maintainer: Raymond Danner <dannerR@uncw.edu>
Repository: CRAN
Date/Publication: 2019-03-05 19:10:09 UTC
Built: R 4.6.0; ; 2026-04-25 22:28:41 UTC; unix
