# Generated by roxygen2: do not edit by hand

export(SongEvo)
export(h.test)
export(mod.val)
export(par.opt)
export(par.sens)
import(geosphere)
import(lattice)
import(sp)
importFrom(boot,boot)
importFrom(boot,boot.ci)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,var)
